# coding=utf-8

"""Checkers for python source files"""

import aslint.common_checkers as COMM
from aslint.base_checkers import (FileContentCat, TextMsg,
                                  checkers_from_context, search_msg)


class LineTooLong(FileContentCat, COMM.LineTooLong):

    """Line too long
    Lines must not be too long for readability and convention.
    Maximum line length is 80 columns in python
    (see http://www.python.org/dev/peps/pep-0008)."""
    id = "C4001"
    _maxlength = 300


class LicenseNotFound(FileContentCat, COMM.LicenseNotFound):

    """Summary with GPL is required
    The copyright and GPL summary are required. Even if there is an external
    copyright, it must mention www.code-aster.org
    See `fix_license` tool (use --help option for details)."""
    id = "C4002"
    fixme = "$HOME/dev/codeaster/devtools/bin/fix_license %(filenames)s"

class EDFCopyright(FileContentCat, COMM.EDFCopyright):

    """EDF R&D Copyright not found
    Even if there is a copyright to another company than EDF R&D, the source
    has been changed for Code_Aster conformance and/or version management.
    Example:

       - Copyright 2008 Company ABC
       - Copyright 2008-2013 EDF R&D www.code-aster.org
    """
    id = "C4003"


class ExternalCopyright(FileContentCat, COMM.ExternalCopyright):

    """Another Copyright than EDF"""
    id = "W4004"


class EncodingDeclNotFound(FileContentCat, COMM.EncodingDeclNotFound):

    """Encoding definition is required in the first or second line
    Conforming to PEP0263, the encoding of the source file must be defined
    by placing a magic comment as first or second line of the file
    (see http://www.python.org/dev/peps/pep-0263/)."""
    id = "C4005"


class InvalidCharacter(FileContentCat, COMM.InvalidCharacter):

    r"""Invalid character, unexpected tabulation '\t'
    Tabulation character is not allowed."""
    id = "C4006"


class ExecUsed(FileContentCat, TextMsg):

    """Using 'exec()' is discouraged"""
    id = "C4007"
    search = search_msg(r"\b(?P<main>exec *\(.*)")


CHECK_LIST = checkers_from_context(globals(), TextMsg)
